==> gcr-3.3.1.1.tar.xz: gcr-3.3.1.1/gcr/gcr-openssh.h <==
/*
 * gnome-keyring
 *
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Author: Stef Walter <stefw@collabora.co.uk>
 */

#if !defined (__GCR_H_INSIDE__) && !defined (GCR_COMPILATION)
#error "Only <gcr/gcr.h> can be included directly."
#endif

#ifndef __GCR_OPENSSH_H__
#define __GCR_OPENSSH_H__

#include <glib.h>

#include <gck/gck.h>

G_BEGIN_DECLS

typedef void             (*GcrOpensshPubCallback)          (GckAttributes *attrs,
                                                            const gchar *label,
                                                            const gchar *options,
                                                            const gchar *outer,
                                                            gsize n_outer,
                                                            gpointer user_data);

guint                    _gcr_openssh_pub_parse            (gconstpointer data,
                                                            gsize n_data,
                                                            GcrOpensshPubCallback callback,
                                                            gpointer user_data);

G_END_DECLS

#endif /* __GCR_OPENSSH_H__ */

==> gcr-3.3.2.tar.xz: gcr-3.3.2/gcr/gcr-openssh.h <==
/*
 * gnome-keyring
 *
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Author: Stef Walter <stefw@collabora.co.uk>
 */

#if !defined (__GCR_H_INSIDE__) && !defined (GCR_COMPILATION)
#error "Only <gcr/gcr.h> can be included directly."
#endif

#ifndef __GCR_OPENSSH_H__
#define __GCR_OPENSSH_H__

#include <glib.h>

#include <gck/gck.h>

#include <egg/egg-bytes.h>

G_BEGIN_DECLS

typedef void             (*GcrOpensshPubCallback)          (GckAttributes *attrs,
                                                            const gchar *label,
                                                            const gchar *options,
                                                            EggBytes *outer,
                                                            gpointer user_data);

guint                    _gcr_openssh_pub_parse            (EggBytes *data,
                                                            GcrOpensshPubCallback callback,
                                                            gpointer user_data);

G_END_DECLS

#endif /* __GCR_OPENSSH_H__ */
